################################################################
:mod:`.navigation <highcharts_core.options.navigation>`
################################################################

.. contents:: Module Contents
  :local:
  :depth: 3
  :backlinks: entry

.. toctree::
  :titlesonly:

  bindings

-------------------------

.. module:: highcharts_core.options.navigation

********************************************************************************************************************
class: :class:`Navigation <highcharts_core.options.navigation.Navigation>`
********************************************************************************************************************

.. autoclass:: Navigation
  :members:
  :inherited-members:

  .. collapse:: Class Inheritance

    .. inheritance-diagram:: Navigation
      :top-classes: highcharts_core.metaclasses.HighchartsMeta
      :parts: -1

  |

-------------------------

***************************
Sub-components
***************************

.. list-table::
  :widths: 60 40
  :header-rows: 1

  * - Module
    - Classes / Functions
  * - :mod:`.options.navigation <highcharts_core.options.navigation>`
    - :class:`Navigation <highcharts_core.options.navigation.Navigation>`
  * - :mod:`.options.navigation.bindings <highcharts_core.options.navigation.bindings>`
    - :class:`Bindings <highcharts_core.options.navigation.bindings.Bindings>`
      :class:`RectangleAnnotationBinding <highcharts_core.options.navigation.bindings.RectangleAnnotationBinding>`
      :class:`LabelAnnotationBinding <highcharts_core.options.navigation.bindings.LabelAnnotationBinding>`
      :class:`EllipseAnnotationBinding <highcharts_core.options.navigation.bindings.EllipseAnnotationBinding>`
      :class:`CircleAnnotationBinding <highcharts_core.options.navigation.bindings.CircleAnnotationBinding>`
      :class:`Binding <highcharts_core.options.navigation.bindings.Binding>`
